@@ -2,6 +2,7 @@ import hashlib
 import pickle
 from threading import currentThread
 
+from django.core.cache import cache
 from django.core.cache.backends.locmem import LocMemCache
 
 from floraconcierge.errors import MiddlewareError
@@ -26,19 +27,30 @@ def new_request_cache(cachecls):
 
 def cached(function):
     def _make_key(args, kwargs):
-        data = [function.__name__, args[0].__class__.__name__, pickle.dumps((args[1:], kwargs))]
+        if args and hasattr(args[0], 'get') and hasattr(args[0], 'add'):
+            data = [function.__name__, args[0].__class__.__name__, pickle.dumps((args[1:], kwargs))]
+        else:
+            data = [function.__name__, pickle.dumps((args[1:], kwargs))]
 
         return hashlib.md5("%".join(data)).hexdigest()
 
     def inner(*args, **kwargs):
         key = _make_key(args, kwargs)
-        obj = args[0]
+        if args and hasattr(args[0], 'get') and hasattr(args[0], 'add'):
+            obj = args[0]
 
-        if key in obj:
-            return obj.get(key)
+            if key in obj:
+                return obj.get(key)
+            else:
+                result = function(*args, **kwargs)
+                obj.add(key, result)
+
+                return result
         else:
-            result = function(*args, **kwargs)
-            obj.add(key, result)
+            result = cache.get(key)
+            if not result:
+                result = function(*args, **kwargs)
+                cache.set(key, result)
 
             return result
 
